unit RASAPI;

interface

uses
  SysUtils, Windows, Dialogs, Classes, ExtCtrls, Forms, Messages;

{
{* Copyright (c) 1992-1995, Microsoft Corporation, all rights reserved
**
** ras.h
** Remote Access external API
** Public header for external API clients
*}

const
{ These are from lmcons.h }
  DNLEN            = 15;  // Maximum domain name length
  UNLEN            = 256; // Maximum user name length
  PWLEN            = 256; // Maximum password length
  NETBIOS_NAME_LEN = 16;  // NetBIOS net name (bytes)

  RAS_MaxDeviceType     = 16;
  RAS_MaxPhoneNumber    = 128;
  RAS_MaxIpAddress      = 15;
  RAS_MaxIpxAddress     = 21;
  RAS_MaxEntryName      = 256;
  RAS_MaxDeviceName     = 128;
  RAS_MaxCallbackNumber = RAS_MaxPhoneNumber;

type
  LPHRasConn = ^THRasConn;
  THRasConn  = Longint;

{* Identifies an active RAS connection.  (See RasEnumConnections) *}
  LPRasConnW = ^TRasConnW;
  TRasConnW  = record
    dwSize       : Longint;
    hrasconn     : THRasConn;
    szEntryName  : Array[0..RAS_MaxEntryName] of WideChar;
    szDeviceType : Array[0..RAS_MaxDeviceType] of WideChar;
    szDeviceName : Array[0..RAS_MaxDeviceName] of WideChar;
  end;

  LPRasConnA = ^TRasConnA;
  TRasConnA  = record
    dwSize       : Longint;
    hrasconn     : THRasConn;
    szEntryName  : Array[0..RAS_MaxEntryName] of AnsiChar;
    szDeviceType : Array[0..RAS_MaxDeviceType] of AnsiChar;
    szDeviceName : Array[0..RAS_MaxDeviceName] of AnsiChar;
  end;

  LPRasConn = ^TRasConn;
  TRasConn  = TRasConnA;

const
{* Enumerates intermediate states to a connection.  (See RasDial) *}
  RASCS_PAUSED = $1000;
  RASCS_DONE   = $2000;

type
  LPRasConnState = ^TRasConnState;
  TRasConnState  = Integer;

const
  RASCS_OpenPort                  = 0;
  RASCS_PortOpened                = 1;
  RASCS_ConnectDevice             = 2;
  RASCS_DeviceConnected           = 3;
  RASCS_AllDevicesConnected       = 4;
  RASCS_Authenticate              = 5;
  RASCS_AuthNotify                = 6;
  RASCS_AuthRetry                 = 7;
  RASCS_AuthCallback              = 8;
  RASCS_AuthChangePassword        = 9;
  RASCS_AuthProject               = 10;
  RASCS_AuthLinkSpeed             = 11;
  RASCS_AuthAck                   = 12;
  RASCS_ReAuthenticate            = 13;
  RASCS_Authenticated             = 14;
  RASCS_PrepareForCallback        = 15;
  RASCS_WaitForModemReset         = 16;
  RASCS_WaitForCallback           = 17;
  RASCS_Projected                 = 18;
  RASCS_StartAuthentication       = 19;
  RASCS_CallbackComplete          = 20;
  RASCS_LogonNetwork              = 21;

  RASCS_Interactive               = RASCS_PAUSED;
  RASCS_RetryAuthentication       = RASCS_PAUSED + 1;
  RASCS_CallbackSetByCaller       = RASCS_PAUSED + 2;
  RASCS_PasswordExpired           = RASCS_PAUSED + 3;

  RASCS_Connected                 = RASCS_DONE;
  RASCS_Disconnected              = RASCS_DONE + 1;

type
{* Describes the status of a RAS connection.  (See RasConnectionStatus)*}
  LPRasConnStatusW = ^TRasConnStatusW;
  TRasConnStatusW  = record
    dwSize         : Longint;
    rasconnstate   : TRasConnState;
    dwError        : LongInt;
    szDeviceType   : Array[0..RAS_MaxDeviceType] of WideChar;
    szDeviceName   : Array[0..RAS_MaxDeviceName] of WideChar;
  end;

  LPRasConnStatusA = ^TRasConnStatusA;
  TRasConnStatusA  = record
    dwSize         : Longint;
    rasconnstate   : TRasConnState;
    dwError        : LongInt;
    szDeviceType   : Array[0..RAS_MaxDeviceType] of AnsiChar;
    szDeviceName   : Array[0..RAS_MaxDeviceName] of AnsiChar;
  end;

  LPRasConnStatus = ^TRasConnStatus;
  TRasConnStatus  = TRasConnStatusA;

{* Describes connection establishment parameters.  (See RasDial)*}
  LPRasDialParamsW = ^TRasDialParamsW;
  TRasDialParamsW  = record
    dwSize           : LongInt;
    szEntryName      : Array[0..RAS_MaxEntryName] of WideChar;
    szPhoneNumber    : Array[0..RAS_MaxPhoneNumber] of WideChar;
    szCallbackNumber : Array[0..RAS_MaxCallbackNumber] of WideChar;
    szUserName       : Array[0..UNLEN] of WideChar;
    szPassword       : Array[0..PWLEN] of WideChar;
    szDomain         : Array[0..DNLEN] of WideChar;
  end;

  LPRasDialParamsA = ^TRasDialParamsA;
  TRasDialParamsA  = record
    dwSize           : LongInt;
    szEntryName      : Array[0..RAS_MaxEntryName] of AnsiChar;
    szPhoneNumber    : Array[0..RAS_MaxPhoneNumber] of AnsiChar;
    szCallbackNumber : Array[0..RAS_MaxCallbackNumber] of AnsiChar;
    szUserName       : Array[0..UNLEN] of AnsiChar;
    szPassword       : Array[0..PWLEN] of AnsiChar;
    szDomain         : Array[0..DNLEN] of AnsiChar;
  end;

  LPRasDialParams = ^TRasDialParams;
  TRasDialParams  = TRasDialParamsA;

{* Describes extended connection establishment options.  (See RasDial)*}
  LPRasDialExtensions = ^TRasDialExtensions;
  TRasDialExtensions  = record
    dwSize            : LongInt;
    dwfOptions        : LongInt;
    hwndParent        : HWND;
    reserved          : LongInt;
  end;

const
{* 'dwfOptions' bit flags.*}
  RDEOPT_UsePrefixSuffix           = $00000001;
  RDEOPT_PausedStates              = $00000002;
  RDEOPT_IgnoreModemSpeaker        = $00000004;
  RDEOPT_SetModemSpeaker           = $00000008;
  RDEOPT_IgnoreSoftwareCompression = $00000010;
  RDEOPT_SetSoftwareCompression    = $00000020;


type

{* Describes an enumerated RAS phone book entry name.  (See RasEntryEnum)*}
  LPRasEntryNameW = ^TRasEntryNameW;
  TRasEntryNameW  = record
    dwSize        : Longint;
    szEntryName   : Array[0..RAS_MaxEntryName] of WideChar;
  end;

  LPRasEntryNameA = ^TRasEntryNameA;
  TRasEntryNameA  = record
    dwSize        : Longint;
    szEntryName   : Array[0..RAS_MaxEntryName] of AnsiChar;
  end;

  LPRasEntryName = ^TRasEntryName;
  TRasEntryName  = TRasEntryNameA;

{* Protocol code to projection data structure mapping.*}
  LPRasProjection = ^TRasProjection;
  TRasProjection  = Integer;

const
  RASP_Amb        = $10000;
  RASP_PppNbf     = $803F;
  RASP_PppIpx     = $802B;
  RASP_PppIp      = $8021;


type
{* Describes the result of a RAS AMB (Authentication Message Block)
** projection.  This protocol is used with NT 3.1 and OS/2 1.3 downlevel
** RAS servers.*}
  LPRasAmbW = ^TRasAmbW;
  TRasAmbW  = record
    dwSize         : Longint;
    dwError        : Longint;
    szNetBiosError : Array[0..NETBIOS_NAME_LEN] of WideChar;
    bLana          : Byte;
  end;

  LPRasAmbA = ^TRasAmbA;
  TRasAmbA  = record
    dwSize         : Longint;
    dwError        : Longint;
    szNetBiosError : Array[0..NETBIOS_NAME_LEN] of AnsiChar;
    bLana          : Byte;
  end;

  LPRasAmb = ^TRasAmb;
  TRasAmb  = TRasAmbA;

{* Describes the result of a PPP NBF (NetBEUI) projection.*}
  LPRasPppNbfW = ^TRasPppNbfW;
  TRasPppNbfW  = record
    dwSize             : Longint;
    dwError            : Longint;
    dwNetBiosError     : Longint;
    szNetBiosError     : Array[0..NETBIOS_NAME_LEN] of WideChar;
    szWorkstationName  : Array[0..NETBIOS_NAME_LEN] of WideChar;
    bLana              : Byte;
  end;

  LPRasPppNbfA = ^TRasPppNbfA;
  TRasPppNbfA  = record
    dwSize             : Longint;
    dwError            : Longint;
    dwNetBiosError     : Longint;
    szNetBiosError     : Array[0..NETBIOS_NAME_LEN] of AnsiChar;
    szWorkstationName  : Array[0..NETBIOS_NAME_LEN] of AnsiChar;
    bLana              : Byte;
  end;

  LpRaspppNbf = ^TRasPppNbf;
  TRasPppNbf  = TRasPppNbfA;

{* Describes the results of a PPP IPX (Internetwork Packet Exchange)
** projection.*}
  LPRasPppIpxW = ^TRasPppIpxW;
  TRasPppIpxW  = record
    dwSize       : Longint;
    dwError      : Longint;
    szIpxAddress : Array[0..RAS_MaxIpxAddress] of WideChar;
  end;

  LPRasPppIpxA = ^TRasPppIpxA;
  TRasPppIpxA  = record
    dwSize       : Longint;
    dwError      : Longint;
    szIpxAddress : Array[0..RAS_MaxIpxAddress] of AnsiChar;
  end;

  LPRasPppIpx = ^TRasPppIpx;
  TRasPppIpx  = TRasPppIpxA;

{* Describes the results of a PPP IP (Internet) projection.*}
  LPRasPppIpW = ^TRasPppIpW;
  TRasPppIpW  = record
    dwSize      : Longint;
    dwError     : Longint;
    szIpAddress : Array[0..RAS_MaxIpAddress] of WideChar;

{$IFNDEF WINNT35COMPATIBLE}
    {* This field was added between Windows NT 3.51 beta and Windows NT 3.51
    ** final, and between Windows 95 M8 beta and Windows 95 final.  If you do
    ** not require the server address and wish to retrieve PPP IP information
    ** from Windows NT 3.5 or early Windows NT 3.51 betas, or on early Windows
    ** 95 betas, define WINNT35COMPATIBLE.
    **
    ** The server IP address is not provided by all PPP implementations,
    ** though Windows NT server's do provide it.    *}
    szServerIpAddress: Array[0..RAS_MaxIpAddress] of WideChar;
{$ENDIF}
  end;

  LPRasPppIpA = ^TRasPppIpA;
  TRasPppIpA  = record
    dwSize      : Longint;
    dwError     : Longint;
    szIpAddress : Array[0..RAS_MaxIpAddress] of AnsiChar;

{$IFNDEF WINNT35COMPATIBLE} {* See RASPPPIPW comment. *}
    szServerIpAddress: Array[0..RAS_MaxIpAddress] of AnsiChar;
{$ENDIF}
  end;

  LPRasPppIp = ^TRasPppIp;
  TRasPppIp  = TRasPppIpA;


const
{* If using RasDial message notifications, get the notification message code
** by passing this string to the RegisterWindowMessageA() API.
** WM_RASDIALEVENT is used only if a unique message cannot be registered.*}
  RASDIALEVENT    = 'RasDialEvent';
  WM_RASDIALEVENT = $CCCD;


{* Prototypes for caller's RasDial callback handler.  Arguments are the
** message ID (currently always WM_RASDIALEVENT), the current RASCONNSTATE and
** the error that has occurred (or 0 if none).  Extended arguments are the
** handle of the RAS connection and an extended error code.
*}
{
typedef VOID (WINAPI *RASDIALFUNC)( UINT, RASCONNSTATE, DWORD );
typedef VOID (WINAPI *RASDIALFUNC1)( HRASCONN, UINT, RASCONNSTATE, DWORD, DWORD );

For Delphi: Just define the callback as
procedure RASCallback(msg: Integer; state: TRasConnState;
    dwError: Longint); stdcall;
 or
procedure RASCallback1(hConn: THRasConn; msg: Integer;
    state: TRasConnState; dwError: Longint; dwEexterror: Longint); stdcall;
}

{* External RAS API function prototypes.
*}
{Note: for Delphi the function without 'A' or 'W' is the Ansi one
  as on the other Delphi headers}

function RasDialA(lpRasDialExt: LPRasDialExtensions; lpszPhoneBook: PAnsiChar;
                  var params: TRasDialParamsA; dwNotifierType: Longint;
                  lpNotifier: Pointer; var rasconn: THRasConn): Longint; stdcall;
function RasDialW(lpRasDialExt: LPRasDialExtensions; lpszPhoneBook: PWideChar;
                  var params: TRasDialParamsW; dwNotifierType: Longint;
                  lpNotifier: Pointer; var rasconn: THRasConn): Longint; stdcall;
function RasDial(lpRasDialExt: LPRasDialExtensions; lpszPhoneBook: PAnsiChar;
        var params: TRasDialParams; dwNotifierType: Longint;
  lpNotifier: Pointer; var rasconn: THRasConn): Longint; stdcall;

function RasEnumConnectionsA(RasConnArray: LPRasConnA; var lpcb: Longint;
                             var lpcConnections: Longint): Longint; stdcall;
function RasEnumConnectionsW(RasConnArray: LPRasConnW; var lpcb: Longint;
                             var lpcConnections: Longint): Longint; stdcall;
function RasEnumConnections(RasConnArray: LPRasConn; var lpcb: Longint;
                             var lpcConnections: Longint): Longint; stdcall;

function RasEnumEntriesA(Reserved: PAnsiChar; lpszPhoneBook: PAnsiChar;
                         entrynamesArray: LPRasEntryNameA; var lpcb: Longint;
                         var lpcEntries: Longint): Longint; stdcall;
function RasEnumEntriesW(reserved: PWideChar; lpszPhoneBook: PWideChar;
                         entrynamesArray: LPRasEntryNameW; var lpcb: Longint;
                         var lpcEntries: Longint): Longint; stdcall;
function RasEnumEntries(reserved: PAnsiChar; lpszPhoneBook: PAnsiChar;
           entrynamesArray: LPRasEntryName; var lpcb: Longint;
                    var lpcEntries: Longint): Longint; stdcall;

function RasGetConnectStatusA(hConn: THRasConn; var lpStatus: TRasConnStatusA): Longint; stdcall;
function RasGetConnectStatusW(hConn: THRasConn;var lpStatus: TRasConnStatusW): Longint; stdcall;
function RasGetConnectStatus(hConn: THRasConn;var lpStatus: TRasConnStatus): Longint; stdcall;

function RasGetErrorStringA(errorValue: Integer;erroString: PAnsiChar;cBufSize: Longint): Longint; stdcall;
function RasGetErrorStringW(errorValue: Integer;erroString: PWideChar;cBufSize: Longint): Longint; stdcall;
function RasGetErrorString(errorValue: Integer;erroString: PAnsiChar;cBufSize: Longint): Longint; stdcall;

function RasHangUpA(hConn: THRasConn): Longint; stdcall;
function RasHangUpW(hConn: THRasConn): Longint; stdcall;
function RasHangUp(hConn: THRasConn): Longint; stdcall;

function RasGetProjectionInfoA(hConn: THRasConn; rasproj: TRasProjection;
                               lpProjection: Pointer; var lpcb: Longint): Longint; stdcall;
function RasGetProjectionInfoW(hConn: THRasConn; rasproj: TRasProjection;
                               lpProjection: Pointer; var lpcb: Longint): Longint; stdcall;
function RasGetProjectionInfo(hConn: THRasConn; rasproj: TRasProjection;
                              lpProjection: Pointer; var lpcb: Longint): Longint; stdcall;

function RasCreatePhonebookEntryA(hwndParentWindow: HWND;lpszPhoneBook: PAnsiChar): Longint; stdcall;
function RasCreatePhonebookEntryW(hwndParentWindow: HWND;lpszPhoneBook: PWideChar): Longint; stdcall;
function RasCreatePhonebookEntry(hwndParentWindow: HWND;lpszPhoneBook: PAnsiChar): Longint; stdcall;

function RasEditPhonebookEntryA(hwndParentWindow: HWND; lpszPhoneBook: PAnsiChar;
                                lpszEntryName: PAnsiChar): Longint; stdcall;
function RasEditPhonebookEntryW(hwndParentWindow: HWND; lpszPhoneBook: PWideChar;
                                lpszEntryName: PWideChar): Longint; stdcall;
function RasEditPhonebookEntry(hwndParentWindow: HWND; lpszPhoneBook: PAnsiChar;
                               lpszEntryName: PAnsiChar): Longint; stdcall;

function RasSetEntryDialParamsA(lpszPhoneBook: PAnsiChar; var lpDialParams: TRasDialParamsA;
                                fRemovePassword: LongBool): Longint; stdcall;
function RasSetEntryDialParamsW(lpszPhoneBook: PWideChar; var lpDialParams: TRasDialParamsW;
                                fRemovePassword: LongBool): Longint; stdcall;
function RasSetEntryDialParams(lpszPhoneBook: PAnsiChar; var lpDialParams: TRasDialParams;
                               fRemovePassword: LongBool): Longint; stdcall;

function RasGetEntryDialParamsA(lpszPhoneBook: PAnsiChar; var lpDialParams: TRasDialParamsA;
                                var lpfPassword: LongBool): Longint; stdcall;
function RasGetEntryDialParamsW(lpszPhoneBook: PWideChar; var lpDialParams: TRasDialParamsW;
                                var lpfPassword: LongBool): Longint; stdcall;
function RasGetEntryDialParams(lpszPhoneBook: PAnsiChar; var lpDialParams: TRasDialParams;
                               var lpfPassword: LongBool): Longint; stdcall;

{**
** raserror.h
** Remote Access external API
** RAS specific error codes *}

const
  RASBASE = 600;
  SUCCESS = 0;

  PENDING                              = (RASBASE+0);
  ERROR_INVALID_PORT_HANDLE            = (RASBASE+1);
  ERROR_PORT_ALREADY_OPEN              = (RASBASE+2);
  ERROR_BUFFER_TOO_SMALL               = (RASBASE+3);
  ERROR_WRONG_INFO_SPECIFIED           = (RASBASE+4);
  ERROR_CANNOT_SET_PORT_INFO           = (RASBASE+5);
  ERROR_PORT_NOT_CONNECTED             = (RASBASE+6);
  ERROR_EVENT_INVALID                  = (RASBASE+7);
  ERROR_DEVICE_DOES_NOT_EXIST          = (RASBASE+8);
  ERROR_DEVICETYPE_DOES_NOT_EXIST      = (RASBASE+9);
  ERROR_BUFFER_INVALID                 = (RASBASE+10);
  ERROR_ROUTE_NOT_AVAILABLE            = (RASBASE+11);
  ERROR_ROUTE_NOT_ALLOCATED            = (RASBASE+12);
  ERROR_INVALID_COMPRESSION_SPECIFIED  = (RASBASE+13);
  ERROR_OUT_OF_BUFFERS                 = (RASBASE+14);
  ERROR_PORT_NOT_FOUND                 = (RASBASE+15);
  ERROR_ASYNC_REQUEST_PENDING          = (RASBASE+16);
  ERROR_ALREADY_DISCONNECTING          = (RASBASE+17);
  ERROR_PORT_NOT_OPEN                  = (RASBASE+18);
  ERROR_PORT_DISCONNECTED              = (RASBASE+19);
  ERROR_NO_ENDPOINTS                   = (RASBASE+20);
  ERROR_CANNOT_OPEN_PHONEBOOK          = (RASBASE+21);
  ERROR_CANNOT_LOAD_PHONEBOOK          = (RASBASE+22);
  ERROR_CANNOT_FIND_PHONEBOOK_ENTRY    = (RASBASE+23);
  ERROR_CANNOT_WRITE_PHONEBOOK         = (RASBASE+24);
  ERROR_CORRUPT_PHONEBOOK              = (RASBASE+25);
  ERROR_CANNOT_LOAD_STRING             = (RASBASE+26);
  ERROR_KEY_NOT_FOUND                  = (RASBASE+27);
  ERROR_DISCONNECTION                  = (RASBASE+28);
  ERROR_REMOTE_DISCONNECTION           = (RASBASE+29);
  ERROR_HARDWARE_FAILURE               = (RASBASE+30);
  ERROR_USER_DISCONNECTION             = (RASBASE+31);
  ERROR_INVALID_SIZE                   = (RASBASE+32);
  ERROR_PORT_NOT_AVAILABLE             = (RASBASE+33);
  ERROR_CANNOT_PROJECT_CLIENT          = (RASBASE+34);
  ERROR_UNKNOWN                        = (RASBASE+35);
  ERROR_WRONG_DEVICE_ATTACHED          = (RASBASE+36);
  ERROR_BAD_STRING                     = (RASBASE+37);
  ERROR_REQUEST_TIMEOUT                = (RASBASE+38);
  ERROR_CANNOT_GET_LANA                = (RASBASE+39);
  ERROR_NETBIOS_ERROR                  = (RASBASE+40);
  ERROR_SERVER_OUT_OF_RESOURCES        = (RASBASE+41);
  ERROR_NAME_EXISTS_ON_NET             = (RASBASE+42);
  ERROR_SERVER_GENERAL_NET_FAILURE     = (RASBASE+43);
  WARNING_MSG_ALIAS_NOT_ADDED          = (RASBASE+44);
  ERROR_AUTH_INTERNAL                  = (RASBASE+45);
  ERROR_RESTRICTED_LOGON_HOURS         = (RASBASE+46);
  ERROR_ACCT_DISABLED                  = (RASBASE+47);
  ERROR_PASSWD_EXPIRED                 = (RASBASE+48);
  ERROR_NO_DIALIN_PERMISSION           = (RASBASE+49);
  ERROR_SERVER_NOT_RESPONDING          = (RASBASE+50);
  ERROR_FROM_DEVICE                    = (RASBASE+51);
  ERROR_UNRECOGNIZED_RESPONSE          = (RASBASE+52);
  ERROR_MACRO_NOT_FOUND                = (RASBASE+53);
  ERROR_MACRO_NOT_DEFINED              = (RASBASE+54);
  ERROR_MESSAGE_MACRO_NOT_FOUND        = (RASBASE+55);
  ERROR_DEFAULTOFF_MACRO_NOT_FOUND     = (RASBASE+56);
  ERROR_FILE_COULD_NOT_BE_OPENED       = (RASBASE+57);
  ERROR_DEVICENAME_TOO_LONG            = (RASBASE+58);
  ERROR_DEVICENAME_NOT_FOUND           = (RASBASE+59);
  ERROR_NO_RESPONSES                   = (RASBASE+60);
  ERROR_NO_COMMAND_FOUND               = (RASBASE+61);
  ERROR_WRONG_KEY_SPECIFIED            = (RASBASE+62);
  ERROR_UNKNOWN_DEVICE_TYPE            = (RASBASE+63);
  ERROR_ALLOCATING_MEMORY              = (RASBASE+64);
  ERROR_PORT_NOT_CONFIGURED            = (RASBASE+65);
  ERROR_DEVICE_NOT_READY               = (RASBASE+66);
  ERROR_READING_INI_FILE               = (RASBASE+67);
  ERROR_NO_CONNECTION                  = (RASBASE+68);
  ERROR_BAD_USAGE_IN_INI_FILE          = (RASBASE+69);
  ERROR_READING_SECTIONNAME            = (RASBASE+70);
  ERROR_READING_DEVICETYPE             = (RASBASE+71);
  ERROR_READING_DEVICENAME             = (RASBASE+72);
  ERROR_READING_USAGE                  = (RASBASE+73);
  ERROR_READING_MAXCONNECTBPS          = (RASBASE+74);
  ERROR_READING_MAXCARRIERBPS          = (RASBASE+75);
  ERROR_LINE_BUSY                      = (RASBASE+76);
  ERROR_VOICE_ANSWER                   = (RASBASE+77);
  ERROR_NO_ANSWER                      = (RASBASE+78);
  ERROR_NO_CARRIER                     = (RASBASE+79);
  ERROR_NO_DIALTONE                    = (RASBASE+80);
  ERROR_IN_COMMAND                     = (RASBASE+81);
  ERROR_WRITING_SECTIONNAME            = (RASBASE+82);
  ERROR_WRITING_DEVICETYPE             = (RASBASE+83);
  ERROR_WRITING_DEVICENAME             = (RASBASE+84);
  ERROR_WRITING_MAXCONNECTBPS          = (RASBASE+85);
  ERROR_WRITING_MAXCARRIERBPS          = (RASBASE+86);
  ERROR_WRITING_USAGE                  = (RASBASE+87);
  ERROR_WRITING_DEFAULTOFF             = (RASBASE+88);
  ERROR_READING_DEFAULTOFF             = (RASBASE+89);
  ERROR_EMPTY_INI_FILE                 = (RASBASE+90);
  ERROR_AUTHENTICATION_FAILURE         = (RASBASE+91);
  ERROR_PORT_OR_DEVICE                 = (RASBASE+92);
  ERROR_NOT_BINARY_MACRO               = (RASBASE+93);
  ERROR_DCB_NOT_FOUND                  = (RASBASE+94);
  ERROR_STATE_MACHINES_NOT_STARTED     = (RASBASE+95);
  ERROR_STATE_MACHINES_ALREADY_STARTED = (RASBASE+96);
  ERROR_PARTIAL_RESPONSE_LOOPING       = (RASBASE+97);
  ERROR_UNKNOWN_RESPONSE_KEY           = (RASBASE+98);
  ERROR_RECV_BUF_FULL                  = (RASBASE+99);
  ERROR_CMD_TOO_LONG                   = (RASBASE+100);
  ERROR_UNSUPPORTED_BPS                = (RASBASE+101);
  ERROR_UNEXPECTED_RESPONSE            = (RASBASE+102);
  ERROR_INTERACTIVE_MODE               = (RASBASE+103);
  ERROR_BAD_CALLBACK_NUMBER            = (RASBASE+104);
  ERROR_INVALID_AUTH_STATE             = (RASBASE+105);
  ERROR_WRITING_INITBPS                = (RASBASE+106);
  ERROR_X25_DIAGNOSTIC                 = (RASBASE+107);
  ERROR_ACCT_EXPIRED                   = (RASBASE+108);
  ERROR_CHANGING_PASSWORD              = (RASBASE+109);
  ERROR_OVERRUN                        = (RASBASE+110);
  ERROR_RASMAN_CANNOT_INITIALIZE       = (RASBASE+111);
  ERROR_BIPLEX_PORT_NOT_AVAILABLE      = (RASBASE+112);
  ERROR_NO_ACTIVE_ISDN_LINES           = (RASBASE+113);
  ERROR_NO_ISDN_CHANNELS_AVAILABLE     = (RASBASE+114);
  ERROR_TOO_MANY_LINE_ERRORS           = (RASBASE+115);
  ERROR_IP_CONFIGURATION               = (RASBASE+116);
  ERROR_NO_IP_ADDRESSES                = (RASBASE+117);
  ERROR_PPP_TIMEOUT                    = (RASBASE+118);
  ERROR_PPP_REMOTE_TERMINATED          = (RASBASE+119);
  ERROR_PPP_NO_PROTOCOLS_CONFIGURED    = (RASBASE+120);
  ERROR_PPP_NO_RESPONSE                = (RASBASE+121);
  ERROR_PPP_INVALID_PACKET             = (RASBASE+122);
  ERROR_PHONE_NUMBER_TOO_LONG          = (RASBASE+123);
  ERROR_IPXCP_NO_DIALOUT_CONFIGURED    = (RASBASE+124);
  ERROR_IPXCP_NO_DIALIN_CONFIGURED     = (RASBASE+125);
  ERROR_IPXCP_DIALOUT_ALREADY_ACTIVE   = (RASBASE+126);
  ERROR_ACCESSING_TCPCFGDLL            = (RASBASE+127);
  ERROR_NO_IP_RAS_ADAPTER              = (RASBASE+128);
  ERROR_SLIP_REQUIRES_IP               = (RASBASE+129);
  ERROR_PROJECTION_NOT_COMPLETE        = (RASBASE+130);
  ERROR_PROTOCOL_NOT_CONFIGURED        = (RASBASE+131);
  ERROR_PPP_NOT_CONVERGING             = (RASBASE+132);
  ERROR_PPP_CP_REJECTED                = (RASBASE+133);
  ERROR_PPP_LCP_TERMINATED             = (RASBASE+134);
  ERROR_PPP_REQUIRED_ADDRESS_REJECTED  = (RASBASE+135);
  ERROR_PPP_NCP_TERMINATED             = (RASBASE+136);
  ERROR_PPP_LOOPBACK_DETECTED          = (RASBASE+137);
  ERROR_PPP_NO_ADDRESS_ASSIGNED        = (RASBASE+138);
  ERROR_CANNOT_USE_LOGON_CREDENTIALS   = (RASBASE+139);
  ERROR_TAPI_CONFIGURATION             = (RASBASE+140);
  ERROR_NO_LOCAL_ENCRYPTION            = (RASBASE+141);
  ERROR_NO_REMOTE_ENCRYPTION           = (RASBASE+142);
  ERROR_REMOTE_REQUIRES_ENCRYPTION     = (RASBASE+143);
  ERROR_IPXCP_NET_NUMBER_CONFLICT      = (RASBASE+144);
  ERROR_INVALID_SMM                    = (RASBASE+145);
  ERROR_SMM_UNINITIALIZED              = (RASBASE+146);
  ERROR_NO_MAC_FOR_PORT                = (RASBASE+147);
  ERROR_SMM_TIMEOUT                    = (RASBASE+148);
  ERROR_BAD_PHONE_NUMBER               = (RASBASE+149);
  ERROR_WRONG_MODULE                   = (RASBASE+150);

  RASBASEEND                           = (RASBASE+150);

{* Copyright (c) 1995, Microsoft Corporation, all rights reserved
**
** rnaph.h  (to be merged with ras.h)
**
** Remote Access external API
** Public header for external API clients
**}

{*
   Original conversion by Gideon le Grange <legrang@adept.co.za>
   Merged with ras.pas by Davide Moretti <dmoretti@iper.net>
*}

const
  RAS_MaxAreaCode   =  10;
  RAS_MaxPadType    =  32;
  RAS_MaxX25Address = 200;
  RAS_MaxFacilities = 200;
  RAS_MaxUserData   = 200;


type
(* Describes a RAS IP Address *)
  LPRasIPAddr = ^TRasIPAddr;
  TRasIPAddr = record
    A, B, C, D: Byte;
  end;

(* Describes a RAS phonebook entry *)
  LPRasEntryA = ^TRasEntryA;
  TRasEntryA  = record
    dwSize,
    dwfOptions,
    dwCountryID,
    dwCountryCode          : Longint;
    szAreaCode             : array[0.. RAS_MaxAreaCode] of AnsiChar;
    szLocalPhoneNumber     : array[0..RAS_MaxPhoneNumber] of AnsiChar;
    dwAlternatesOffset     : Longint;
    ipaddr,
    ipaddrDns,
    ipaddrDnsAlt,
    ipaddrWins,
    ipaddrWinsAlt          : TRasIPAddr;
    dwFrameSize,
    dwfNetProtocols,
    dwFramingProtocol      : Longint;
    szScript               : Array[0..MAX_PATH - 1] of AnsiChar;
    szAutodialDll          : Array [0..MAX_PATH - 1] of AnsiChar;
    szAutodialFunc         : Array [0..MAX_PATH - 1] of AnsiChar;
    szDeviceType           : Array [0..RAS_MaxDeviceType] of AnsiChar;
    szDeviceName           : Array [0..RAS_MaxDeviceName] of AnsiChar;
    szX25PadType           : Array [0..RAS_MaxPadType] of AnsiChar;
    szX25Address           : Array [0..RAS_MaxX25Address] of AnsiChar;
    szX25Facilities        : Array [0..RAS_MaxFacilities] of AnsiChar;
    szX25UserData          : Array [0..RAS_MaxUserData] of AnsiChar;
    dwChannels,
    dwReserved1,
    dwReserved2            : Longint;
  end;

  LPRasEntryW = ^TRasEntryW;
  TRasEntryW  = record
    dwSize,
    dwfOptions,
    dwCountryID,
    dwCountryCode          : Longint;
    szAreaCode             : array[0.. RAS_MaxAreaCode] of WideChar;
    szLocalPhoneNumber     : array[0..RAS_MaxPhoneNumber] of WideChar;
    dwAlternatesOffset     : Longint;
    ipaddr,
    ipaddrDns,
    ipaddrDnsAlt,
    ipaddrWins,
    ipaddrWinsAlt          : TRasIPAddr;
    dwFrameSize,
    dwfNetProtocols,
    dwFramingProtocol      : Longint;
    szScript               : Array[0..MAX_PATH - 1] of WideChar;
    szAutodialDll          : Array [0..MAX_PATH - 1] of WideChar;
    szAutodialFunc         : Array [0..MAX_PATH - 1] of WideChar;
    szDeviceType           : Array [0..RAS_MaxDeviceType] of WideChar;
    szDeviceName           : Array [0..RAS_MaxDeviceName] of WideChar;
    szX25PadType           : Array [0..RAS_MaxPadType] of WideChar;
    szX25Address           : Array [0..RAS_MaxX25Address] of WideChar;
    szX25Facilities        : Array [0..RAS_MaxFacilities] of WideChar;
    szX25UserData          : Array [0..RAS_MaxUserData] of WideChar;
    dwChannels,
    dwReserved1,
    dwReserved2            : Longint;
  end;

  LPRasEntry = ^TRasEntry;
  TRasEntry  = TRasEntryA;

(* Describes Country Information *)
  LPRasCtryInfo = ^TRasCtryInfo;
  TRasCtryInfo  = record
    dwSize,
    dwCountryID,
    dwNextCountryID,
    dwCountryCode,
    dwCountryNameOffset : Longint;
  end;

(* Describes RAS Device Information *)
  LPRasDevInfoA = ^TRasDevInfoA;
  TRasDevInfoA  = record
    dwSize       : Longint;
    szDeviceType : Array[0..RAS_MaxDeviceType] of AnsiChar;
    szDeviceName : Array[0..RAS_MaxDeviceName] of AnsiChar;
  end;

  LPRasDevInfoW = ^TRasDevInfoW;
  TRasDevInfoW  = record
    dwSize       : Longint;
    szDeviceType : Array[0..RAS_MaxDeviceType] of WideChar;
    szDeviceName : Array[0..RAS_MaxDeviceName] of WideChar;
  end;

  LPRasDevInfo = ^TRasDevInfo;
  TRasDevInfo  = TRasDevInfoA;

const
(* TRasEntry 'dwfOptions' bit flags. *)
  RASEO_UseCountryAndAreaCodes = $00000001;
  RASEO_SpecificIpAddr         = $00000002;
  RASEO_SpecificNameServers    = $00000004;
  RASEO_IpHeaderCompression    = $00000008;
  RASEO_RemoteDefaultGateway   = $00000010;
  RASEO_DisableLcpExtensions   = $00000020;
  RASEO_TerminalBeforeDial     = $00000040;
  RASEO_TerminalAfterDial      = $00000080;
  RASEO_ModemLights            = $00000100;
  RASEO_SwCompression          = $00000200;
  RASEO_RequireEncryptedPw     = $00000400;
  RASEO_RequireMsEncryptedPw   = $00000800;
  RASEO_RequireDataEncryption  = $00001000;
  RASEO_NetworkLogon           = $00002000;
  RASEO_UseLogonCredentials    = $00004000;
  RASEO_PromoteAlternates      = $00008000;

(* TRasEntry 'dwfNetProtocols' bit flags. (session negotiated protocols) *)
  RASNP_Netbeui = $00000001;  // Negotiate NetBEUI
  RASNP_Ipx     = $00000002;  // Negotiate IPX
  RASNP_Ip      = $00000004;  // Negotiate TCP/IP

(* TRasEntry 'dwFramingProtocols' (framing protocols used by the server) *)
  RASFP_Ppp  = $00000001;  // Point-to-Point Protocol (PPP)
  RASFP_Slip = $00000002;  // Serial Line Internet Protocol (SLIP)
  RASFP_Ras  = $00000004;  // Microsoft proprietary protocol

(* TRasEntry 'szDeviceType' strings *)
  RASDT_Modem = 'modem';     // Modem
  RASDT_Isdn  = 'isdn';      // ISDN
  RASDT_X25   = 'x25';      // X.25

(* RAS functions found in RNAPH.DLL *)
function RasValidateEntryNameA(lpszPhonebook,szEntry: PAnsiChar): Longint; stdcall;
function RasValidateEntryNameW(lpszPhonebook,szEntry: PWideChar): Longint; stdcall;
function RasValidateEntryName(lpszPhonebook,szEntry: PAnsiChar): Longint; stdcall;

function RasRenameEntryA(lpszPhonebook,szEntryOld,szEntryNew: PAnsiChar): Longint; stdcall;
function RasRenameEntryW(lpszPhonebook,szEntryOld,szEntryNew: PWideChar): Longint; stdcall;
function RasRenameEntry(lpszPhonebook,szEntryOld,szEntryNew: PAnsiChar): Longint; stdcall;

function RasDeleteEntryA(lpszPhonebook,szEntry: PAnsiChar): Longint; stdcall;
function RasDeleteEntryW(lpszPhonebook,szEntry: PWideChar): Longint; stdcall;
function RasDeleteEntry(lpszPhonebook,szEntry: PAnsiChar): Longint; stdcall;

function RasGetEntryPropertiesA(lpszPhonebook, szEntry: PAnsiChar; lpbEntry: Pointer;
                                var lpdwEntrySize: Longint; lpbDeviceInfo: Pointer;
                                var lpdwDeviceInfoSize: Longint): Longint; stdcall;
function RasGetEntryPropertiesW(lpszPhonebook, szEntry: PWideChar; lpbEntry: Pointer;
                                var lpdwEntrySize: Longint; lpbDeviceInfo: Pointer;
                                var lpdwDeviceInfoSize: Longint): Longint; stdcall;
function RasGetEntryProperties(lpszPhonebook, szEntry: PAnsiChar; lpbEntry: Pointer;
                                var lpdwEntrySize: Longint; lpbDeviceInfo: Pointer;
                                var lpdwDeviceInfoSize: Longint): Longint; stdcall;

function RasSetEntryPropertiesA(lpszPhonebook, szEntry: PAnsiChar; lpbEntry: Pointer;
                                dwEntrySize: Longint; lpbDeviceInfo: Pointer;
                                dwDeviceInfoSize: Longint): Longint; stdcall;
function RasSetEntryPropertiesW(lpszPhonebook, szEntry: PWideChar; lpbEntry: Pointer;
                                dwEntrySize: Longint; lpbDeviceInfo: Pointer;
                                dwDeviceInfoSize: Longint): Longint; stdcall;
function RasSetEntryProperties(lpszPhonebook, szEntry: PAnsiChar; lpbEntry: Pointer;
                               dwEntrySize: Longint; lpbDeviceInfo: Pointer;
                               dwDeviceInfoSize: Longint): Longint; stdcall;

function RasGetCountryInfoA(var lpCtryInfo: TRasCtryInfo;var lpdwSize: Longint): Longint; stdcall;
function RasGetCountryInfoW(var lpCtryInfo: TRasCtryInfo;var lpdwSize: Longint): Longint; stdcall;
function RasGetCountryInfo(var lpCtryInfo: TRasCtryInfo;var lpdwSize: Longint): Longint; stdcall;

function RasEnumDevicesA(lpBuff: LpRasDevInfoA; var lpcbSize: Longint;
                         var lpcDevices: Longint): Longint; stdcall;
function RasEnumDevicesW(lpBuff: LpRasDevInfoW; var lpcbSize: Longint;
                         var lpcDevices: Longint): Longint; stdcall;
function RasEnumDevices(lpBuff: LpRasDevInfo; var lpcbSize: Longint;
                         var lpcDevices: Longint): Longint; stdcall;

{******************************************************}
function StatusStrin_g(State: TRasConnState): String;
function GetErrorString(Ret:integer):string;
function StringToArray(S:string;var ar:array of char):boolean;
function ArrayToArray(ar1:array of char;var ar2:array of char):boolean;

implementation
{****************************************************************************}

{~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~}
function RasCreatePhonebookEntryA; external 'rasapi32.dll' name 'RasCreatePhonebookEntryA';
function RasCreatePhonebookEntryW; external 'rasapi32.dll' name 'RasCreatePhonebookEntryW';
function RasCreatePhonebookEntry;  external 'rasapi32.dll' name 'RasCreatePhonebookEntryA';
function RasDialA;                 external 'rasapi32.dll' name 'RasDialA';
function RasDialW;                 external 'rasapi32.dll' name 'RasDialW';
function RasDial;                  external 'rasapi32.dll' name 'RasDialA';
function RasEditPhonebookEntryA;   external 'rasapi32.dll' name 'RasEditPhonebookEntryA';
function RasEditPhonebookEntryW;   external 'rasapi32.dll' name 'RasEditPhonebookEntryW';
function RasEditPhonebookEntry;    external 'rasapi32.dll' name 'RasEditPhonebookEntryA';
function RasEnumConnectionsA;      external 'rasapi32.dll' name 'RasEnumConnectionsA';
function RasEnumConnectionsW;      external 'rasapi32.dll' name 'RasEnumConnectionsW';
function RasEnumConnections;       external 'rasapi32.dll' name 'RasEnumConnectionsA';
function RasEnumEntriesA;          external 'rasapi32.dll' name 'RasEnumEntriesA';
function RasEnumEntriesW;          external 'rasapi32.dll' name 'RasEnumEntriesW';
function RasEnumEntries;           external 'rasapi32.dll' name 'RasEnumEntriesA';
function RasGetConnectStatusA;     external 'rasapi32.dll' name 'RasGetConnectStatusA';
function RasGetConnectStatusW;     external 'rasapi32.dll' name 'RasGetConnectStatusW';
function RasGetConnectStatus;      external 'rasapi32.dll' name 'RasGetConnectStatusA';
function RasGetEntryDialParamsA;   external 'rasapi32.dll' name 'RasGetEntryDialParamsA';
function RasGetEntryDialParamsW;   external 'rasapi32.dll' name 'RasGetEntryDialParamsW';
function RasGetEntryDialParams;    external 'rasapi32.dll' name 'RasGetEntryDialParamsA';
function RasGetErrorStringA;       external 'rasapi32.dll' name 'RasGetErrorStringA';
function RasGetErrorStringW;       external 'rasapi32.dll' name 'RasGetErrorStringW';
function RasGetErrorString;        external 'rasapi32.dll' name 'RasGetErrorStringA';
function RasGetProjectionInfoA;    external 'rasapi32.dll' name 'RasGetProjectionInfoA';
function RasGetProjectionInfoW;    external 'rasapi32.dll' name 'RasGetProjectionInfoW';
function RasGetProjectionInfo;     external 'rasapi32.dll' name 'RasGetProjectionInfoA';
function RasHangUpA;               external 'rasapi32.dll' name 'RasHangUpA';
function RasHangUpW;               external 'rasapi32.dll' name 'RasHangUpW';
function RasHangUp;                external 'rasapi32.dll' name 'RasHangUpA';
function RasSetEntryDialParamsA;   external 'rasapi32.dll' name 'RasSetEntryDialParamsA';
function RasSetEntryDialParamsW;   external 'rasapi32.dll' name 'RasSetEntryDialParamsW';
function RasSetEntryDialParams;    external 'rasapi32.dll' name 'RasSetEntryDialParamsA';
function RasValidateEntryNameA;  external 'rasapi32.dll' name 'RasValidateEntryNameA';
function RasValidateEntryNameW;  external 'rasapi32.dll' name 'RasValidateEntryNameW';
function RasRenameEntryA;        external 'rasapi32.dll' name 'RasRenameEntryA';
function RasRenameEntryW;        external 'rasapi32.dll' name 'RasRenameEntryW';
function RasDeleteEntryA;        external 'rasapi32.dll' name 'RasDeleteEntryA';
function RasDeleteEntryW;        external 'rasapi32.dll' name 'RasDeleteEntryW';
function RasGetEntryPropertiesA; external 'rasapi32.dll' name 'RasGetEntryPropertiesA';
function RasGetEntryPropertiesW; external 'rasapi32.dll' name 'RasGetEntryPropertiesW';
function RasSetEntryPropertiesA; external 'rasapi32.dll' name 'RasSetEntryPropertiesA';
function RasSetEntryPropertiesW; external 'rasapi32.dll' name 'RasSetEntryPropertiesW';
function RasGetCountryInfoA;     external 'rasapi32.dll' name 'RasGetCountryInfoA';
function RasGetCountryInfoW;     external 'rasapi32.dll' name 'RasGetCountryInfoW';
function RasEnumDevicesA;        external 'rasapi32.dll' name 'RasEnumDevicesA';
function RasEnumDevicesW;        external 'rasapi32.dll' name 'RasEnumDevicesW';

var
  Rnaph_Initialized       : Boolean = False;
  Is_Rnaph                : Boolean = False;
  Lib                     : HModule;

function StatusStrin_g(State: TRasConnState): String;
var
S:string;
begin
    S:='';
    case State of
      RASCS_OpenPort:
        S:=' ';
      RASCS_PortOpened:
        S:=' ';
      RASCS_ConnectDevice:
        S:=' ';
      RASCS_DeviceConnected:
        S:=' ';
      RASCS_AllDevicesConnected:
        S:='  ';
      RASCS_Authenticate:
        S:=' ';
      RASCS_AuthNotify:
        S:=' ';
      RASCS_AuthRetry:
        S:='  ';
      RASCS_AuthCallback:
        S:='   ';
      RASCS_AuthChangePassword:
        S:='   ';
      RASCS_AuthProject:
        S:='  ';
      RASCS_AuthLinkSpeed:
        S:='   ';
      RASCS_AuthAck:
        S:='  ';
      RASCS_ReAuthenticate:
        S:='   ';
      RASCS_Authenticated:
        S:=' ';
      RASCS_PrepareForCallback:
        S:='   ';
      RASCS_WaitForModemReset:
        S:='  ';
      RASCS_WaitForCallback:
        S:='  ';
      RASCS_Projected:
        S:='';
      RASCS_StartAuthentication:
        S:='  ';
      RASCS_CallbackComplete:
        S:='   ';
      RASCS_LogonNetwork:
        S:='  ';

      RASCS_Interactive:
        S:='';
      RASCS_RetryAuthentication:
        S:='  ';
      RASCS_CallbackSetByCaller:
        S:=' ,    ';
      RASCS_PasswordExpired:
        S:=' ';

      RASCS_Connected:
        S:='';
      RASCS_Disconnected:
        S:='';
    end;
    Result:=S;
end;

function StringToArray(S:string;var ar:array of char):boolean;
var
I,LenString,LenAr:integer;
begin
try
S:=Trim(S);
LenString:=Length(S);
LenAr:=High(ar);
for I:=0 to LenAr do
               ar[I]:= #0;

for I:=0 to LenString do
                 ar[I-1]:=S[I];
except
Result:=false;
exit;
end;
Result:=true;
end;

function ArrayToArray(ar1:array of char;var ar2:array of char):boolean;
var
I,LenAr:integer;
begin
try
LenAr:=High(ar2);
for I:=0 to LenAr do
               ar2[I]:= #0;

for I:=0 to LenAr do
               ar2[I]:= ar1[I];
except
Result:=false;
exit;
end;
Result:=true;
end;


function GetErrorString(Ret:integer):string;
var
S:string;
begin
SetLength(S,255);
RasGetErrorString(Ret,PChar(s),255);
SetLength(S,Pos(#0,S));
Result:=S;
end;

{~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~}

function Rnaph_(const func: String): Pointer;
begin
  if not Rnaph_Initialized then
  begin
    // Try first with RASAPI32.DLL
    Lib:=LoadLibrary('rasapi32.dll');
    if Lib<>0 then
    begin
      Result:=GetProcAddress(Lib, PChar(Func+'A'));
      if Result<>nil then
      begin
        Rnaph_Initialized:=True;
        Exit;
      end;
    end else raise Exception.Create('Error opening rasapi.dll');
    // function not found - try rnaph.dll
    Lib:=LoadLibrary('rnaph.dll');
    if Lib<>0 then
    begin
      Result:=GetProcAddress(Lib, PChar(Func));
      if Result <> nil then
      begin
        Rnaph_Initialized:=True;
        Is_Rnaph:=True;
        Exit;
      end else raise Exception.Create('Function '+Func+' not found!');
    end else raise Exception.Create('Error opening rnaph.dll');
  end else
  begin
    if Is_Rnaph then Result:=GetProcAddress(Lib,PChar(Func))
    else Result:=GetProcAddress(lib,PChar(Func+'A'));
    if Result=nil then raise Exception.Create('Function '+Func+' not found!');
  end;
end;

{~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~}

function RasValidateEntryName(lpszPhonebook, szEntry: PAnsiChar): Longint;
var
  F      : Function(lpszPhonebook, szEntry: PAnsiChar): Longint; stdcall;
begin
  @F:=Rnaph_('RasValidateEntryName');
  Result:=F(lpszPhonebook, szEntry);
end;

{~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~}

function RasRenameEntry(lpszPhonebook, szEntryOld, szEntryNew: PAnsiChar): Longint;
var
  F      : function(lpszPhonebook, szEntryOld, szEntryNew: PAnsiChar): Longint; stdcall;
begin
  @F:=rnaph_('RasRenameEntry');
  Result:=F(lpszPhonebook, szEntryOld, szEntryNew);
end;

{~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~}

function RasDeleteEntry(lpszPhonebook, szEntry: PAnsiChar): Longint;
var
  F      : function(lpszPhonebook, szEntry: PAnsiChar): Longint; stdcall;
begin
  @F:=Rnaph_('RasDeleteEntry');
  Result:=F(lpszPhonebook, szEntry);
end;

{~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~}

function RasGetEntryProperties(lpszPhonebook, szEntry: PAnsiChar; lpbEntry: Pointer;
    var lpdwEntrySize: Longint; lpbDeviceInfo: Pointer;
    var lpdwDeviceInfoSize: Longint): Longint;
var
  F                  : function(lpszPhonebook, szEntry: PAnsiChar; lpbEntry: Pointer;
                                lpdwEntrySize      : Longint;
                                lpbDeviceInfo      : Pointer;
                                lpdwDeviceInfoSize : Longint): Longint; stdcall;
begin
  @F:=Rnaph_('RasGetEntryProperties');
  Result:=F(lpszPhonebook, szEntry, lpbEntry, lpdwEntrySize, lpbDeviceInfo, lpdwDeviceInfoSize);
end;

{~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~}

function RasSetEntryProperties(lpszPhonebook, szEntry: PAnsiChar;
	  lpbEntry: Pointer; dwEntrySize: Longint; lpbDeviceInfo: Pointer;
    dwDeviceInfoSize: Longint): Longint;
var
  F                   : function(lpszPhonebook, szEntry: PAnsiChar;
                                 lpbEntry: Pointer; dwEntrySize: Longint;
                                 lpbDeviceInfo: Pointer;
                                 dwDeviceInfoSize: Longint): Longint; stdcall;
begin
  @F:=Rnaph_('RasSetEntryProperties');
  Result:=F(lpszPhonebook, szEntry, lpbEntry, dwEntrySize, lpbDeviceInfo, dwDeviceInfoSize);
end;

{~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~}

function RasGetCountryInfo(var lpCtryInfo: TRasCtryInfo; var lpdwSize: Longint): Longint;
var
  F                   : function(var lpCtryInfo: TRasCtryInfo;
                                 var lpdwSize: Longint): Longint; stdcall;
begin
  @F:=Rnaph_('RasGetCountryInfo');
  Result:=F(lpCtryInfo, lpdwSize);
end;

{~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~}

function RasEnumDevices(lpBuff: LpRasDevInfo; var lpcbSize: Longint;
                        var lpcDevices: Longint): Longint;
var
  F                   : function(lpBuff: LpRasDevInfo; var lpcbSize: Longint;
                                 var lpcDevices: Longint): Longint; stdcall;
begin
  @F:=Rnaph_('RasEnumDevices');
  Result:=F(lpBuff, lpcbSize, lpcDevices);
end;

{~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~}


initialization

finalization
  if Rnaph_initialized and Is_rnaph then FreeLibrary(lib);
end.


